<template>
    <el-dialog
        v-dialogDrag
        title="选择广场舞地点"
        :visible="visible"
        destroy-on-close
        :before-close="handleClose"
        :close-on-click-modal="false"
        v-if="visible"
        width="70%"
        top="4vh"
        :class="[loading ? 'dialog-box' : '']"
    >
        <div class="table-wrapper">
            <div class="search-wrapper">
                <el-input
                    style="width: 400px"
                    clearable
                    v-model="reqData.querys[0].value"
                    @change="getData(1)"
                    suffix-icon="el-icon-search"
                    placeholder="请输入广场舞地点名称/备注名称/详细地址查询"
                />
                行政区划：
                <el-cascader
                    ref="cascaders"
                    v-model="areaList"
                    :props="{label: 'name', value: 'code', checkStrictly: true}"
                    @change="handleChange"
                    :options="options"
                    placeholder="请输入行政区划"
                ></el-cascader>
                <el-button
                    style="margin-left: 20px"
                    icon="el-icon-plus"
                    type="primary"
                    @click="handleAddPalce"
                    >新增地点</el-button
                >
            </div>
            <el-table
                stripe
                ref="table"
                size="mini"
                height="400"
                :data="tableData"
                v-loading="loading"
                highlight-current-row
                :row-key="getRowKey"
                reserce-selection
                @current-change="currentChange"
                @selection-change="handleSelectionChange"
            >
                <el-table-column
                    v-if="isMultiple"
                    type="selection"
                    align="center"
                    width="55"
                >
                </el-table-column>
                <el-table-column type="index" label="序号" align="center">
                </el-table-column>
                <el-table-column
                    prop="squareLocationName"
                    show-overflow-tooltip
                    label="广场名称"
                    align="center"
                    min-width="200"
                >
                </el-table-column>
                <el-table-column
                    prop="areaFullName"
                    show-overflow-tooltip
                    label="行政区划"
                    align="center"
                    min-width="200"
                >
                    <template v-slot="{row}">
                        {{
                            row.areaFullName.split('/')[
                                row.areaFullName.split('/').length - 1
                            ]
                        }}
                    </template>
                </el-table-column>
                <el-table-column
                    prop="detailAddress"
                    show-overflow-tooltip
                    label="详细地址"
                    min-width="200"
                    align="center"
                >
                </el-table-column>
                <el-table-column
                    prop="noiseTypeName"
                    show-overflow-tooltip
                    label="噪音分类"
                    align="center"
                >
                </el-table-column>
                <el-table-column
                    prop="noiseLevelName"
                    show-overflow-tooltip
                    label="噪音级别"
                    align="center"
                >
                </el-table-column>
            </el-table>
        </div>
        <pagination
            ref="paginationPanel"
            style="margin-top: 10px"
            :pageResult="reqData.pageBean"
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
        />
        <div
            slot="footer"
            class="dialog-footer"
            :style="loading ? 'position: relative;z-index: -1;' : ''"
        >
            <!-- :disabled="currentRow && currentRow.id ? false : true" -->
            <el-button
                :disabled="
                    isMultiple
                        ? !multipleSelection.length
                        : currentRow && currentRow.id
                        ? false
                        : true
                "
                type="primary"
                @click="handleSubmit"
                >确定</el-button
            >
            <el-button @click="handleClose">取消</el-button>
        </div>
        <PlazaLocationDialog
            ref="formDialog"
            @getData="getData"
        ></PlazaLocationDialog>
    </el-dialog>
</template>
<script>
import pagination from '@/components/pagination'
import plazaLocation from '@/api/basicConfiguration/PlazaLocation'
import PlazaLocationDialog from './PlazaLocationDialog.vue'
import Team from '@/api/basicConfiguration/Team'
export default {
    name: 'placesDialog',
    components: {
        pagination,
        PlazaLocationDialog,
    },
    props: {
        isMultiple: {
            type: Boolean,
            default: false,
        },
    },
    data() {
        return {
            visible: false,
            loading: false,
            multipleSelection: [],
            chooseList: [],
            reqData: {
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'searchIn',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'l.area_full_code_',
                        relation: 'AND',
                        value: '',
                    },
                ],
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
                sorter: [
                    {
                        direction: 'DESC',
                        property: 'createTime',
                    },
                ],
            },
            tableData: [],
            currentRow: null,
            options: [],
            areaList: [],
        }
    },
    methods: {
        handleAddPalce() {
            this.$refs.formDialog.open()
        },
        open(data) {
            this.visible = true
            if (data) {
                this.chooseList = data
            }
            this.areaList = this.$store.state.user.currentUserDetail.org[0]
                .orgAddvcdFull
                ? this.$store.state.user.currentUserDetail.org[0].orgAddvcdFull
                      .split('/')
                      .splice(1)
                : []
            this.reqData.querys[1].value =
                this.$store.state.user.currentUserDetail.org[0].orgAddvcdFull
            this.getTownTree()
            this.getData()
        },
        handleClose() {
            this.visible = false
        },
        handleSubmit() {
            if (this.isMultiple) {
                let arr = this.multipleSelection.map((it) => {
                    return {
                        squareLocationName: it.squareLocationName,
                        squareLocationId: it.id,
                        areaCode: it.areaCode,
                        areaFullCode: it.areaFullCode,
                    }
                })
                this.$emit('changePlaces', arr)
                this.$refs.table.clearSelection()
            } else {
                this.$emit('changePlaces', {
                    squareLocationName: this.currentRow.squareLocationName,
                    id: this.currentRow.id,
                    areaCode: this.currentRow.areaCode,
                    areaFullCode: this.currentRow.areaFullCode,
                })
            }
            this.visible = false
            this.currentRow = null
            this.tableData = []
        },
        currentChange(currentRow, oldCurrentRow) {
            this.currentRow = currentRow
        },
        getData(page) {
            this.loading = true
            page ? (this.reqData.pageBean.page = page) : null
            plazaLocation.dataQuery(this.reqData, (res) => {
                this.reqData.pageBean.total = res.total
                this.loading = false
                this.tableData = res.rows
                this.$nextTick(() => {
                    this.chooseList.forEach((item) => {
                        this.tableData.forEach((it) => {
                            if (item.squareLocationId === it.id) {
                                this.$refs.table.toggleRowSelection(it, true)
                            }
                        })
                    })
                })
                console.log('this.tableData', this.tableData)
            })
        },
        handleSizeChange(pageSize) {
            this.reqData.pageBean.pageSize = pageSize
            this.getData(1)
        },
        handleCurrentChange(page) {
            this.reqData.pageBean.page = page
            this.getData()
        },
        handleSelectionChange(val) {
            this.multipleSelection = val
        },
        //获取Id
        getRowKey(row) {
            return row.id
        },
        getTownTree() {
            Team.townTree({}, (res) => {
                if (res.state) {
                    this.options = res.value
                }
            })
        },
        handleChange(val) {
            console.log(val)
            this.reqData.querys[1].value = val[val.length - 1]
            this.getData(1)
        },
    },
}
</script>
<style lang="scss" scoped>
.search-wrapper {
    width: 100%;
    margin-bottom: 10px;
}
</style>